import { z } from "zod";
import { countryNames } from "../utils/Misc";

//! The schema should reflect the database
export namespace CompanySchema {
  export const CompanyAddressBase = z.object({
    postcode: z.string().max(20),
    address_line_1: z.string(),
    address_line_2: z.string(),
    address_line_3: z.string(),
    city_county: z.string(),
    country: z.string(),
  });

  const timeRegex = /^([01]\d|2[0-3]):[0-5]\d(:[0-5]\d)?$/;
  export const CompanyTradingHourBase = z.object({
    company_id: z.number().positive(),
    day_name: z.enum([
      "Sunday",
      "Monday",
      "Tuesday",
      "Wednesday",
      "Thursday",
      "Friday",
      "Saturday",
    ]),
    trade_status: z.number().min(0).max(1),
    opening_time: z.string().regex(timeRegex),
    closing_time: z.string().regex(timeRegex),
  });
}

export namespace APICommon {
  export const PaginationParams = z.object({
    page: z.coerce.number().default(1),
    limit: z.coerce.number().default(10),
  });
}
